@@ -2085,28 +2085,27 @@ class XMIAssociation (XMIElement):
         name = str(self.name)
         if self.name:
             log.debug("self.name is set to '%s', returning it.", name)
-            res = name
+            return name
+        log.debug("self.name isn't set.")
+        if self.fromEnd:
+            fromname = self.fromEnd.getName(ignore_cardinality=1)
+            log.debug("Getting fromname from the startpoint: '%s'.",
+                      fromname)
         else:
-            log.debug("self.name isn't set.")
-            if self.fromEnd:
-                fromname = self.fromEnd.getName(ignore_cardinality=1)
-                log.debug("Getting fromname from the startpoint: '%s'.",
-                          fromname)
-            else:
-                fromname = self.getId()
-                log.debug("Getting fromname from our id: '%s'.", fromname)
-            if self.toEnd:
-                toname = self.toEnd.getName(ignore_cardinality=1)
-                log.debug("Getting toname from the endpoint: '%s'.", toname)
-            else:
-                toname = self.getId()
-                log.debug("Getting toname from our id: '%s'.", toname)
-            res = '%s_%s' % (fromname, toname)
-            log.debug("Combining that fromname and toname to form our "
-                      "relation name: '%s'.", res)
-            if isinstance(res, basestring):
-                res = res.strip().lower()
-                log.debug("Making it lowercase for good measure: '%s'.", res)
+            fromname = self.getId()
+            log.debug("Getting fromname from our id: '%s'.", fromname)
+        if self.toEnd:
+            toname = self.toEnd.getName(ignore_cardinality=1)
+            log.debug("Getting toname from the endpoint: '%s'.", toname)
+        else:
+            toname = self.getId()
+            log.debug("Getting toname from our id: '%s'.", toname)
+        res = '%s_%s' % (fromname, toname)
+        log.debug("Combining that fromname and toname to form our "
+                  "relation name: '%s'.", res)
+        if isinstance(res, basestring):
+            res = res.strip().lower()
+            log.debug("Making it lowercase for good measure: '%s'.", res)
         return res
 
     def getInverseName(self):
@@ -2754,8 +2753,8 @@ def parse(xschemaFileName=None, xschema=None, packages=[], generator=None,**kw):
 
     if xschemaFileName:
         suff = os.path.splitext(xschemaFileName)[1].lower()
-        if suff.lower() in ('.zargo','.zuml','.zip'):
-            log.debug("Opening %s ..." % suff.lower())
+        if suff in ('.zargo','.zuml','.zip'):
+            log.debug("Opening %s ..." % suff)
             zf = ZipFile(xschemaFileName)
             xmis = [n for n in zf.namelist() \
                     if os.path.splitext(n)[1].lower() in ['.xmi','.xml']]
@@ -2772,13 +2771,13 @@ def parse(xschemaFileName=None, xschema=None, packages=[], generator=None,**kw):
         xmiver = str(xmi.getAttribute('xmi.version'))
         log.debug("XMI version: %s", xmiver)
         if xmiver >= "1.2":
-            log.debug("Using xmi 1.2+ parser.")
+            log.debug("Using xmi 1.2 parser.")
             XMI = XMI1_2(**kw)
         elif xmiver >= "1.1":
-            log.debug("Using xmi 1.1+ parser.")
+            log.debug("Using xmi 1.1 parser.")
             XMI = XMI1_1(**kw)
         else:
-            log.debug("Using xmi 1.1+ parser.")
+            log.debug("Using xmi 1.0 parser.")
             XMI = XMI1_0(**kw)
     except:
         log.debug("No version info found, taking XMI1_0.")
